# WaterTAP

This is the WaterTAP development repository.

WaterTAP is developed as part of the [National Alliance for Water Innovation](https://nawihub.org/) project.

## Build Status

[![Checks](https://github.com/watertap-org/watertap/actions/workflows/checks.yml/badge.svg)](https://github.com/watertap-org/watertap/actions/workflows/checks.yml)
[![Documentation Status](https://readthedocs.org/projects/watertap/badge/?version=latest)](https://watertap.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/watertap-org/watertap/branch/main/graph/badge.svg)](https://codecov.io/gh/watertap-org/watertap)  
[![GitHub contributors](https://img.shields.io/github/contributors/watertap-org/watertap.svg)](https://github.com/watertap-org/watertap/graphs/contributors)  
[![Merged PRs](https://img.shields.io/github/issues-pr-closed-raw/watertap-org/watertap.svg?label=merged+PRs)](https://github.com/watertap-org/watertap/pulls?q=is:pr+is:merged)  
[![Issue stats](http://isitmaintained.com/badge/resolution/watertap-org/watertap.svg)](http://isitmaintained.com/project/watertap-org/watertap)

## Getting started

To quickly install and start using WaterTAP, head over to the [Getting Started](https://watertap.readthedocs.io/en/stable/getting_started.html) section of the documentation.

If you wish to use the **WaterTAP UI**, you can [download and install](https://watertap-org.github.io) it from this page: https://watertap-org.github.io.

To run the WaterTAP tutorials online (no installation required), refer to [this guide](https://watertap.readthedocs.io/en/stable/how_to_guides/notebooks.html#online-using-binder-org).

## Documentation

The WaterTAP documentation is available online at <https://watertap.readthedocs.io>.

## Developer Installation

If you want to clone the repository and work directly with the code, please
refer to the [Getting Started for Developers](https://watertap.readthedocs.io/en/stable/getting_started.html#for-watertap-developers) section of the documentation.

## Cite this work

To cite this work, use the "Cite this repository" feature available on the right side of this repository page or use the reference text given below.

> WaterTAP contributors. WaterTAP: An open-source water treatment model library. Version 0.6. Sponsored by California Energy Commission, National Alliance for Water Innovation, and USDOE. Available at https://github.com/watertap-org/watertap.

## Funding Acknowledgements

This work is being conducted as part of the [National Alliance for Water Innovation
(NAWI)](https://www.nawihub.org/) with support through the U.S. Department of Energy’s [Advanced
Manufacturing Office](https://www.energy.gov/eere/amo/advanced-manufacturing-office).
